@@ -4,20 +4,23 @@
 # Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/master/LICENSE
+# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
 
 
 """Astroid hooks for numpy.core.numeric module."""
 
 import functools
 
-import astroid
-
-from .brain_numpy_utils import infer_numpy_member, looks_like_numpy_member
+from astroid.brain.brain_numpy_utils import infer_numpy_member, looks_like_numpy_member
+from astroid.brain.helpers import register_module_extender
+from astroid.builder import parse
+from astroid.inference_tip import inference_tip
+from astroid.manager import AstroidManager
+from astroid.node_classes import Attribute
 
 
 def numpy_core_numeric_transform():
-    return astroid.parse(
+    return parse(
         """
     # different functions defined in numeric.py
     import numpy
@@ -28,8 +31,8 @@ def numpy_core_numeric_transform():
     )
 
 
-astroid.register_module_extender(
-    astroid.MANAGER, "numpy.core.numeric", numpy_core_numeric_transform
+register_module_extender(
+    AstroidManager(), "numpy.core.numeric", numpy_core_numeric_transform
 )
 
 
@@ -41,8 +44,8 @@ METHODS_TO_BE_INFERRED = {
 
 for method_name, function_src in METHODS_TO_BE_INFERRED.items():
     inference_function = functools.partial(infer_numpy_member, function_src)
-    astroid.MANAGER.register_transform(
-        astroid.Attribute,
-        astroid.inference_tip(inference_function),
+    AstroidManager().register_transform(
+        Attribute,
+        inference_tip(inference_function),
         functools.partial(looks_like_numpy_member, method_name),
     )
