@@ -1,15 +1,17 @@
 # Copyright (c) 2006-2011, 2013 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
 # Copyright (c) 2010 Daniel Harding <dharding@gmail.com>
-# Copyright (c) 2014-2018 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2014-2020 Claudiu Popa <pcmanticore@gmail.com>
 # Copyright (c) 2014 Google, Inc.
 # Copyright (c) 2015-2016 Ceridwen <ceridwenv@gmail.com>
 # Copyright (c) 2016 Jared Garst <jgarst@users.noreply.github.com>
 # Copyright (c) 2017 Ashley Whetter <ashley@awhetter.co.uk>
 # Copyright (c) 2017 rr- <rr-@sakuya.pl>
 # Copyright (c) 2018 Bryce Guinta <bryce.paul.guinta@gmail.com>
+# Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
+# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/master/COPYING.LESSER
+# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
 
 """Every available node class.
 
@@ -18,17 +20,21 @@
 
 All nodes inherit from :class:`~astroid.node_classes.NodeNG`.
 """
-# pylint: disable=unused-import,redefined-builtin
 
-from astroid.node_classes import (
+# Nodes not present in the builtin ast module:  DictUnpack, Unknown, and EvaluatedObject.
+
+from astroid.node_classes import (  # pylint: disable=redefined-builtin (Ellipsis)
+    AnnAssign,
     Arguments,
-    AssignAttr,
     Assert,
     Assign,
-    AnnAssign,
+    AssignAttr,
     AssignName,
+    AsyncFor,
+    AsyncWith,
+    Attribute,
     AugAssign,
-    Repr,
+    Await,
     BinOp,
     BoolOp,
     Break,
@@ -39,29 +45,42 @@ from astroid.node_classes import (
     Continue,
     Decorators,
     DelAttr,
-    DelName,
     Delete,
+    DelName,
     Dict,
-    Expr,
+    DictUnpack,
     Ellipsis,
     EmptyNode,
+    EvaluatedObject,
     ExceptHandler,
-    Exec,
+    Expr,
     ExtSlice,
     For,
-    ImportFrom,
-    Attribute,
+    FormattedValue,
     Global,
     If,
     IfExp,
     Import,
+    ImportFrom,
     Index,
+    JoinedStr,
     Keyword,
     List,
+    Match,
+    MatchAs,
+    MatchCase,
+    MatchClass,
+    MatchMapping,
+    MatchOr,
+    MatchSequence,
+    MatchSingleton,
+    MatchStar,
+    MatchValue,
     Name,
+    NamedExpr,
+    NodeNG,
     Nonlocal,
     Pass,
-    Print,
     Raise,
     Return,
     Set,
@@ -72,46 +91,38 @@ from astroid.node_classes import (
     TryFinally,
     Tuple,
     UnaryOp,
+    Unknown,
     While,
     With,
     Yield,
     YieldFrom,
     const_factory,
-    AsyncFor,
-    Await,
-    AsyncWith,
-    FormattedValue,
-    JoinedStr,
-    # Node not present in the builtin ast module.
-    DictUnpack,
-    Unknown,
 )
 from astroid.scoped_nodes import (
-    Module,
+    AsyncFunctionDef,
+    ClassDef,
+    DictComp,
+    FunctionDef,
     GeneratorExp,
     Lambda,
-    DictComp,
     ListComp,
+    Module,
     SetComp,
-    FunctionDef,
-    ClassDef,
-    AsyncFunctionDef,
 )
 
-
 ALL_NODE_CLASSES = (
-    AsyncFunctionDef,
-    AsyncFor,
-    AsyncWith,
-    Await,
+    AnnAssign,
     Arguments,
-    AssignAttr,
     Assert,
     Assign,
-    AnnAssign,
+    AssignAttr,
     AssignName,
+    AsyncFor,
+    AsyncFunctionDef,
+    AsyncWith,
+    Attribute,
     AugAssign,
-    Repr,
+    Await,
     BinOp,
     BoolOp,
     Break,
@@ -120,39 +131,52 @@ ALL_NODE_CLASSES = (
     Compare,
     Comprehension,
     Const,
+    const_factory,
     Continue,
     Decorators,
     DelAttr,
-    DelName,
     Delete,
+    DelName,
     Dict,
     DictComp,
     DictUnpack,
-    Expr,
     Ellipsis,
     EmptyNode,
+    EvaluatedObject,
     ExceptHandler,
-    Exec,
+    Expr,
     ExtSlice,
     For,
-    ImportFrom,
+    FormattedValue,
     FunctionDef,
-    Attribute,
     GeneratorExp,
     Global,
     If,
     IfExp,
     Import,
+    ImportFrom,
     Index,
+    JoinedStr,
     Keyword,
     Lambda,
     List,
     ListComp,
-    Name,
-    Nonlocal,
+    Match,
+    MatchAs,
+    MatchCase,
+    MatchClass,
+    MatchMapping,
+    MatchOr,
+    MatchSequence,
+    MatchSingleton,
+    MatchStar,
+    MatchValue,
     Module,
+    Name,
+    NamedExpr,
+    NodeNG,
+    Nonlocal,
     Pass,
-    Print,
     Raise,
     Return,
     Set,
@@ -164,10 +188,94 @@ ALL_NODE_CLASSES = (
     TryFinally,
     Tuple,
     UnaryOp,
+    Unknown,
     While,
     With,
     Yield,
     YieldFrom,
-    FormattedValue,
-    JoinedStr,
+)
+
+__all__ = (
+    "AnnAssign",
+    "Arguments",
+    "Assert",
+    "Assign",
+    "AssignAttr",
+    "AssignName",
+    "AsyncFor",
+    "AsyncFunctionDef",
+    "AsyncWith",
+    "Attribute",
+    "AugAssign",
+    "Await",
+    "BinOp",
+    "BoolOp",
+    "Break",
+    "Call",
+    "ClassDef",
+    "Compare",
+    "Comprehension",
+    "Const",
+    "const_factory",
+    "Continue",
+    "Decorators",
+    "DelAttr",
+    "Delete",
+    "DelName",
+    "Dict",
+    "DictComp",
+    "DictUnpack",
+    "Ellipsis",
+    "EmptyNode",
+    "EvaluatedObject",
+    "ExceptHandler",
+    "Expr",
+    "ExtSlice",
+    "For",
+    "FormattedValue",
+    "FunctionDef",
+    "GeneratorExp",
+    "Global",
+    "If",
+    "IfExp",
+    "Import",
+    "ImportFrom",
+    "Index",
+    "JoinedStr",
+    "Keyword",
+    "Lambda",
+    "List",
+    "ListComp",
+    "Match",
+    "MatchAs",
+    "MatchCase",
+    "MatchClass",
+    "MatchMapping",
+    "MatchOr",
+    "MatchSequence",
+    "MatchSingleton",
+    "MatchStar",
+    "MatchValue",
+    "Module",
+    "Name",
+    "NamedExpr",
+    "NodeNG",
+    "Nonlocal",
+    "Pass",
+    "Raise",
+    "Return",
+    "Set",
+    "SetComp",
+    "Slice",
+    "Starred",
+    "Subscript",
+    "TryExcept",
+    "TryFinally",
+    "Tuple",
+    "UnaryOp",
+    "Unknown",
+    "While",
+    "With",
+    "Yield",
+    "YieldFrom",
 )
