@@ -8,7 +8,7 @@
 # Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/master/LICENSE
+# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
 
 
 """
@@ -20,9 +20,9 @@ leads to an inferred FrozenSet:
     Call(func=Name('frozenset'), args=Tuple(...))
 """
 
-import builtins
 
 from astroid import bases, decorators, node_classes, scoped_nodes, util
+from astroid.const import BUILTINS
 from astroid.exceptions import (
     AttributeInferenceError,
     InferenceError,
@@ -31,7 +31,6 @@ from astroid.exceptions import (
 )
 from astroid.manager import AstroidManager
 
-BUILTINS = builtins.__name__
 objectmodel = util.lazy_import("interpreter.objectmodel")
 
 
